@@ -10,22 +10,35 @@
 #include "efxc2Utils.h"
 #include "efxc2Compiler.h"
 
-void Compiler::Compile() {
+static void DisplayDefine(D3D_SHADER_MACRO i) {
+    if (i.Name != nullptr && i.Definition != nullptr) {
+        printf(" %s=%s", i.Name, i.Definition);
+    }
+}
 
+void Compiler::Compile() {
     auto SourceCode = params.get_SourceCode();
-    auto SourceLen = params.get_SourceLen();
+    size_t SourceLen = SourceCode->size();
     auto eflags = params.get_eflags();
     auto sflags = params.get_sflags();
     auto secondary_flags = params.get_secondary_flags();
-    auto numDefines = params.get_numDefines();
     std::string _entryPoint = params.get_entryPoint();
     const char* entryPoint = _entryPoint.c_str();
     std::string _model = params.get_model();
     const char* model = _model.c_str();
     std::string _inputFile = params.get_inputFile();
     const char* inputFile = _inputFile.c_str();
-    auto defines = params.get_defines();
-
+    auto _defines = params.get_defines();
+    auto defines = std::make_unique<std::vector<D3D_SHADER_MACRO>>();
+    D3D_SHADER_MACRO _def;
+    for (size_t i = 0; i <  _defines->size(); i++) {
+        _def.Definition = _defines.get()->at(i).Definition.c_str();
+        _def.Name = _defines.get()->at(i).Name.c_str();
+        defines->insert(defines->end(), _def);
+    }
+    _def.Definition = nullptr;
+    _def.Name = nullptr;
+    defines->insert(defines->end(), _def);
     ID3DBlob* errors = nullptr;
     if (params.get_verbose()) {
         printf("Calling D3DCompile2(\n");
@@ -35,16 +48,7 @@ void Compiler::Compile() {
         printf("\t %s, \n", inputFile);
         /* print defines */
         printf("\t");
-#ifdef _MSC_VER
-#pragma warning(push)
-#pragma warning(disable: 6001)
-#pragma warning(disable: 6011)
-#endif
-        for (size_t i = 0; i < numDefines - 1; i++)
-            printf(" %s=%s", defines[i].Name, defines[i].Definition);
-#ifdef _MSC_VER
-#pragma warning(pop)
-#endif
+        std::for_each(defines->begin(), defines->end(), DisplayDefine);
         printf(",\n");
         /* done printing defines */
         printf("\t D3D_COMPILE_STANDARD_FILE_INCLUDE,\n");
@@ -77,16 +81,12 @@ void Compiler::Compile() {
        [out, optional] ID3DBlob               **ppErrorMsgs
      );
     */
-#ifdef _MSC_VER
-#pragma warning( push )
-#pragma warning( disable : 6387)
-#endif
     auto ptr = api.get_ptr_D3DCompile2();
     HRESULT hr = ptr(
         SourceCode.get()->data(),
         SourceLen,
         inputFile,
-        defines,
+        defines->data(),
         D3D_COMPILE_STANDARD_FILE_INCLUDE,
         entryPoint,
         model,
@@ -98,9 +98,6 @@ void Compiler::Compile() {
         &compilerOutput,
         &errors
     );
-#ifdef _MSC_VER
-#pragma warning( pop )
-#endif
     if (FAILED(hr)) {
         if (errors) {
             auto* error = (char*)errors->GetBufferPointer();
@@ -128,7 +125,7 @@ void Compiler::Disassemble() {
         printf("\t %zu,\n", compiledLen);
         printf("\t 0x%016" PRIx64 ", \n", (INT64)disassembly_flags);
         printf("\t nullptr, \n");
-        printf("\t &disassemlyCodeBlob);");
+        printf("\t &disassemlyCodeBlob);\n");
     }
     /*HRESULT D3DDisassemble(
     [in]           LPCVOID  pSrcData,
